summaryrefslogtreecommitdiff
path: root/src/ToolBox/superpmi/superpmi-shared/icorjitinfoimpl.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/ToolBox/superpmi/superpmi-shared/icorjitinfoimpl.h')
-rw-r--r--src/ToolBox/superpmi/superpmi-shared/icorjitinfoimpl.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/ToolBox/superpmi/superpmi-shared/icorjitinfoimpl.h b/src/ToolBox/superpmi/superpmi-shared/icorjitinfoimpl.h
index fe4ed6a5ff..52526fa16f 100644
--- a/src/ToolBox/superpmi/superpmi-shared/icorjitinfoimpl.h
+++ b/src/ToolBox/superpmi/superpmi-shared/icorjitinfoimpl.h
@@ -1017,7 +1017,7 @@ int doAssert(const char* szFile, int iLine, const char* szExpr);
void reportFatalError(CorJitResult result);
/*
-struct ProfileBuffer // Also defined here: code:CORBBTPROF_BLOCK_DATA
+struct BlockCounts // Also defined here: code:CORBBTPROF_BLOCK_DATA
{
ULONG ILOffset;
ULONG ExecutionCount;
@@ -1026,15 +1026,15 @@ struct ProfileBuffer // Also defined here: code:CORBBTPROF_BLOCK_DATA
// allocate a basic block profile buffer where execution counts will be stored
// for jitted basic blocks.
-HRESULT allocBBProfileBuffer(ULONG count, // The number of basic blocks that we have
- ProfileBuffer** profileBuffer);
+HRESULT allocMethodBlockCounts(DWORD count, // The number of basic blocks that we have
+ BlockCounts** pBlockCounts);
// get profile information to be used for optimizing the current method. The format
-// of the buffer is the same as the format the JIT passes to allocBBProfileBuffer.
-HRESULT getBBProfileData(CORINFO_METHOD_HANDLE ftnHnd,
- ULONG* count, // The number of basic blocks that we have
- ProfileBuffer** profileBuffer,
- ULONG* numRuns);
+// of the buffer is the same as the format the JIT passes to allocMethodBlockCounts.
+HRESULT getMethodBlockCounts(CORINFO_METHOD_HANDLE ftnHnd,
+ DWORD* pCount, // The number of basic blocks that we have
+ BlockCounts** pBlockCounts,
+ DWORD* pNumRuns);
// Associates a native call site, identified by its offset in the native code stream, with
// the signature information and method handle the JIT used to lay out the call site. If